.. module:: enaml.widgets.color_dialog

==========================
enaml.widgets.color_dialog
==========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    ColorDialog


.. autoclass:: ColorDialog
